@@ -74,7 +74,7 @@ impl Vertex {
         vec![InputElementDesc::default()
             .set_name("POSITION")
             .unwrap()
-            .set_format(Format::R32G32B32_Float)
+            .set_format(Format::R32G32B32Float)
             .set_input_slot(0)
             .set_offset(ByteCount(offset_of!(Self, position) as u64))]
     }
@@ -588,7 +588,7 @@ impl HelloMeshShadersSample {
         let _debug_printer = make_debug_printer!(&self.info_queue);
 
         let depth_stencil_desc = DepthStencilViewDesc::default()
-            .set_format(Format::D32_Float)
+            .set_format(Format::D32Float)
             .set_view_dimension(DsvDimension::Texture2D)
             .set_flags(DsvFlags::None);
 
@@ -601,7 +601,7 @@ impl HelloMeshShadersSample {
                     .set_dimension(ResourceDimension::Texture2D)
                     .set_width(WINDOW_WIDTH.into())
                     .set_height(WINDOW_HEIGHT.into())
-                    .set_format(Format::D32_Float)
+                    .set_format(Format::D32Float)
                     .set_flags(
                         ResourceFlags::AllowDepthStencil
                             | ResourceFlags::DenyShaderResource,
@@ -609,7 +609,7 @@ impl HelloMeshShadersSample {
                 ResourceStates::DepthWrite,
                 Some(
                     &ClearValue::default()
-                        .set_format(Format::D32_Float)
+                        .set_format(Format::D32Float)
                         .set_depth_stencil(
                             &DepthStencilValue::default()
                                 .set_depth(1.)
@@ -705,7 +705,7 @@ fn create_pipeline_state(
             &DepthStencilDesc::default().set_depth_enable(false),
         )
         .set_primitive_topology_type(PrimitiveTopologyType::Triangle)
-        .set_rtv_formats(&[Format::R8G8B8A8_UNorm]);
+        .set_rtv_formats(&[Format::R8G8B8A8Unorm]);
 
     let pso_desc = PipelineStateStreamDesc::default()
         .set_pipeline_state_subobject_stream(
