@@ -67,7 +67,6 @@ macro_rules! dx_try {
 
 const MAX_FUNC_NAME_LEN: usize = 64;
 const MAX_ERROR_MSG_LEN: usize = 512;
-
 pub struct DxError([u8; MAX_FUNC_NAME_LEN], HRESULT);
 
 impl DxError {
@@ -339,6 +338,7 @@ pub fn d3d_enable_experimental_shader_models() -> DxResult<()> {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Debug {
     pub this: *mut ID3D12Debug5,
 }
@@ -374,6 +374,7 @@ impl Debug {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct InfoQueue {
     pub this: *mut ID3D12InfoQueue1,
 }
@@ -490,6 +491,7 @@ impl InfoQueue {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct DebugDevice {
     pub this: *mut ID3D12DebugDevice,
 }
@@ -531,6 +533,7 @@ impl DebugDevice {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Factory {
     pub this: *mut IDXGIFactory6,
 }
@@ -688,6 +691,7 @@ impl Factory {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Adapter {
     pub this: *mut IDXGIAdapter3,
 }
@@ -705,6 +709,7 @@ impl Adapter {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Device {
     pub this: *mut ID3D12Device2,
 }
@@ -908,9 +913,6 @@ impl Device {
         }
         Ok(DescriptorHeap {
             this: hw_descriptor_heap,
-            handle_size: self.get_descriptor_handle_increment_size(unsafe {
-                std::mem::transmute(desc.0.Type)
-            }),
         })
     }
 
@@ -994,7 +996,7 @@ impl Device {
     pub fn create_placed_resource(
         &self,
         heap: &Heap,
-        heap_offset: Bytes,
+        heap_offset: ByteCount,
         resource_desc: &ResourceDesc,
         initial_state: ResourceStates,
         optimized_clear_value: Option<&ClearValue>,
@@ -1200,8 +1202,8 @@ impl Device {
         resource_desc: &ResourceDesc,
         first_subresouce: u32,
         num_subresources: u32,
-        base_offset: Bytes,
-    ) -> (Vec<PlacedSubresourceFootprint>, Vec<u32>, Vec<Bytes>, Bytes) {
+        base_offset: ByteCount,
+    ) -> (Vec<PlacedSubresourceFootprint>, Vec<u32>, Vec<ByteCount>, ByteCount) {
         let mut placed_subresource_footprints: Vec<PlacedSubresourceFootprint> =
             Vec::with_capacity(num_subresources as usize);
         unsafe {
@@ -1212,7 +1214,7 @@ impl Device {
             Vec::with_capacity(num_subresources as usize);
         unsafe { num_rows.set_len(num_subresources as usize) }
 
-        let mut row_sizes: Vec<Bytes> =
+        let mut row_sizes: Vec<ByteCount> =
             Vec::with_capacity(num_subresources as usize);
         unsafe { row_sizes.set_len(num_subresources as usize) }
 
@@ -1238,21 +1240,21 @@ impl Device {
             placed_subresource_footprints,
             num_rows,
             row_sizes,
-            Bytes(total_bytes),
+            ByteCount(total_bytes),
         )
     }
 
     pub fn get_descriptor_handle_increment_size(
         &self,
         heap_type: DescriptorHeapType,
-    ) -> u32 {
-        unsafe {
+    ) -> ByteCount {
+        ByteCount::from(unsafe {
             dx_call!(
                 self.this,
                 GetDescriptorHandleIncrementSize,
                 heap_type as i32
             )
-        }
+        })
     }
 
     pub fn get_device_removed_reason(&self) -> DxError {
@@ -1369,6 +1371,7 @@ impl Device {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct DeviceChild {
     pub this: *mut ID3D12DeviceChild,
 }
@@ -1406,6 +1409,7 @@ impl From<Fence> for DeviceChild {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct CommandQueue {
     pub this: *mut ID3D12CommandQueue,
 }
@@ -1447,6 +1451,7 @@ impl CommandQueue {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Swapchain {
     pub this: *mut IDXGISwapChain4,
 }
@@ -1492,15 +1497,14 @@ impl Swapchain {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct DescriptorHeap {
     pub this: *mut ID3D12DescriptorHeap,
-    handle_size: u32, // it could be Bytes, but the latter is 64-bit, and
-                      // since it doesn't leak into public interface, there isn't much sense in it
 }
 
-impl_com_object_set_get_name!(DescriptorHeap, handle_size);
-impl_com_object_refcount_unnamed!(DescriptorHeap, handle_size);
-impl_com_object_clone_drop!(DescriptorHeap, handle_size);
+impl_com_object_set_get_name!(DescriptorHeap);
+impl_com_object_refcount_unnamed!(DescriptorHeap);
+impl_com_object_clone_drop!(DescriptorHeap);
 
 unsafe impl Send for DescriptorHeap {}
 
@@ -1516,10 +1520,7 @@ impl DescriptorHeap {
                 &mut hw_handle
             );
         }
-        CpuDescriptorHandle {
-            hw_handle,
-            handle_size: self.handle_size,
-        }
+        CpuDescriptorHandle { hw_handle }
     }
 
     pub fn get_gpu_descriptor_handle_for_heap_start(
@@ -1533,49 +1534,47 @@ impl DescriptorHeap {
                 &mut hw_handle
             );
         }
-        GpuDescriptorHandle {
-            hw_handle,
-            handle_size: self.handle_size,
-        }
+        GpuDescriptorHandle { hw_handle }
     }
 }
 
 #[derive(Copy, Clone, Debug)]
+#[repr(transparent)]
 pub struct CpuDescriptorHandle {
     pub hw_handle: D3D12_CPU_DESCRIPTOR_HANDLE,
-    pub handle_size: u32,
 }
 
 impl CpuDescriptorHandle {
     #[must_use]
-    pub fn advance(self, distance: u32) -> Self {
+    pub fn advance(self, distance: u32, handle_size: ByteCount) -> Self {
         CpuDescriptorHandle {
             hw_handle: D3D12_CPU_DESCRIPTOR_HANDLE {
-                ptr: self.hw_handle.ptr + (distance * self.handle_size) as u64,
+                ptr: self.hw_handle.ptr
+                    + (distance * handle_size.0 as u32) as u64,
             },
-            handle_size: self.handle_size,
         }
     }
 }
 
 #[derive(Debug, Copy, Clone)]
+#[repr(transparent)]
 pub struct GpuDescriptorHandle {
     pub hw_handle: D3D12_GPU_DESCRIPTOR_HANDLE,
-    pub handle_size: u32,
 }
 
 impl GpuDescriptorHandle {
-    pub fn advance(self, distance: u32) -> Self {
+    pub fn advance(self, distance: u32, handle_size: ByteCount) -> Self {
         GpuDescriptorHandle {
             hw_handle: D3D12_GPU_DESCRIPTOR_HANDLE {
-                ptr: self.hw_handle.ptr + (distance * self.handle_size) as u64,
+                ptr: self.hw_handle.ptr
+                    + (distance * handle_size.0 as u32) as u64,
             },
-            handle_size: self.handle_size,
         }
     }
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Resource {
     pub this: *mut ID3D12Resource,
 }
@@ -1616,7 +1615,7 @@ impl Resource {
         &self,
         first_subresouce: u32,
         num_subresources: u32,
-    ) -> DxResult<Bytes> {
+    ) -> DxResult<ByteCount> {
         let resource_desc = self.get_desc();
 
         let device = self.get_device()?;
@@ -1624,7 +1623,7 @@ impl Resource {
             &resource_desc,
             first_subresouce,
             num_subresources,
-            Bytes(0),
+            ByteCount(0),
         );
         device.release();
 
@@ -1668,6 +1667,7 @@ impl Resource {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct CommandAllocator {
     pub this: *mut ID3D12CommandAllocator,
 }
@@ -1685,6 +1685,7 @@ impl CommandAllocator {
 assert_eq_size!(CommandList, *mut ID3D12GraphicsCommandList6);
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct CommandList {
     pub this: *mut ID3D12GraphicsCommandList6,
 }
@@ -1758,10 +1759,10 @@ impl CommandList {
     pub fn copy_buffer_region(
         &self,
         dest: &Resource,
-        dest_offset: Bytes,
+        dest_offset: ByteCount,
         source: &Resource,
-        source_offset: Bytes,
-        span: Bytes,
+        source_offset: ByteCount,
+        span: ByteCount,
     ) {
         unsafe {
             dx_call!(
@@ -1934,7 +1935,7 @@ impl CommandList {
         start_index: u32,
         num_queries: u32,
         destination_buffer: &Resource,
-        aligned_destination_buffer_offset: Bytes,
+        aligned_destination_buffer_offset: ByteCount,
     ) {
         unsafe {
             dx_call!(
@@ -2067,30 +2068,12 @@ impl CommandList {
     }
 
     pub fn set_descriptor_heaps(&self, heaps: &[DescriptorHeap]) {
-        // since DescriptorHeap object is not just a wrapper around
-        // the correspondent COM pointer but also contains another member,
-        // we cannot just pass an array of DescriptorHeap's where
-        // an array of ID3D12DescriptorHeap's is required
-        // one could argue this smells, but it is really convenient
-        // to store descriptor size inside descriptor heap object
-
-        const MAX_HEAP_COUNT: usize = 2;
-        assert!(
-            heaps.len() <= MAX_HEAP_COUNT,
-            "Cannot set more than 2 descriptor heaps"
-        );
-
-        let mut hw_heaps = [std::ptr::null_mut(); MAX_HEAP_COUNT];
-        for i in 0..heaps.len() {
-            hw_heaps[i] = heaps[i].this;
-        }
-
         unsafe {
             dx_call!(
                 self.this,
                 SetDescriptorHeaps,
                 heaps.len() as std::os::raw::c_uint,
-                hw_heaps.as_mut_ptr() as *const *mut ID3D12DescriptorHeap
+                heaps.as_ptr() as *const *mut ID3D12DescriptorHeap
             )
         }
     }
@@ -2298,12 +2281,12 @@ impl CommandList {
         intermediate_resource: &Resource,
         first_subresouce: u32,
         num_subresources: u32,
-        required_size: Bytes,
+        required_size: ByteCount,
         layouts: &[PlacedSubresourceFootprint],
         num_rows: &[u32],
-        row_sizes_in_bytes: &[Bytes],
+        row_sizes_in_bytes: &[ByteCount],
         source_data: &[SubresourceData],
-    ) -> DxResult<Bytes> {
+    ) -> DxResult<ByteCount> {
         // ToDo: implement validation as in the original function
 
         let data = intermediate_resource.map(0, None)?;
@@ -2333,10 +2316,10 @@ impl CommandList {
         if destination_desc.0.Dimension == ResourceDimension::Buffer as i32 {
             self.copy_buffer_region(
                 destination_resource,
-                Bytes(0),
+                ByteCount(0),
                 intermediate_resource,
-                Bytes(layouts[0].0.Offset),
-                Bytes(layouts[0].0.Footprint.Width as u64),
+                ByteCount(layouts[0].0.Offset),
+                ByteCount(layouts[0].0.Footprint.Width as u64),
             );
         } else {
             for i in 0..num_subresources as usize {
@@ -2369,12 +2352,12 @@ impl CommandList {
         &self,
         destination_resource: &Resource,
         intermediate_resource: &Resource,
-        intermediate_offset: Bytes,
+        intermediate_offset: ByteCount,
         first_subresouce: u32,
         num_subresources: u32,
         source_data: &[SubresourceData],
-    ) -> DxResult<Bytes> {
-        let allocation_size = Bytes::from(
+    ) -> DxResult<ByteCount> {
+        let allocation_size = ByteCount::from(
             std::mem::size_of::<PlacedSubresourceFootprint>()
                 + std::mem::size_of::<u32>()
                 + std::mem::size_of::<u64>(),
@@ -2417,7 +2400,7 @@ impl CommandList {
 unsafe fn memcpy_subresource(
     dest: &D3D12_MEMCPY_DEST,
     src: &D3D12_SUBRESOURCE_DATA,
-    row_sizes_in_bytes: Bytes,
+    row_sizes_in_bytes: ByteCount,
     num_rows: u32,
     num_slices: u32,
 ) {
@@ -2437,6 +2420,7 @@ unsafe fn memcpy_subresource(
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Fence {
     pub this: *mut ID3D12Fence,
 }
@@ -2471,6 +2455,7 @@ impl Fence {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Win32Event {
     pub handle: HANDLE,
 }
@@ -2523,6 +2508,7 @@ impl Handle {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct RootSignature {
     pub this: *mut ID3D12RootSignature,
 }
@@ -2563,6 +2549,7 @@ impl RootSignature {
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct PipelineState {
     pub this: *mut ID3D12PipelineState,
 }
@@ -2573,6 +2560,7 @@ impl_com_object_clone_drop!(PipelineState);
 unsafe impl Send for PipelineState {}
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Blob {
     pub this: *mut ID3DBlob,
 }
@@ -2584,13 +2572,14 @@ impl Blob {
         unsafe {
             let buffer_pointer: *mut u8 =
                 dx_call!(self.this, GetBufferPointer,) as *mut u8;
-            let buffer_size: Bytes = Bytes(dx_call!(self.this, GetBufferSize,));
+            let buffer_size: ByteCount = ByteCount(dx_call!(self.this, GetBufferSize,));
             std::slice::from_raw_parts(buffer_pointer, buffer_size.0 as usize)
         }
     }
 }
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct QueryHeap {
     pub this: *mut ID3D12QueryHeap,
 }
@@ -2599,13 +2588,13 @@ impl_com_object_refcount_named!(QueryHeap);
 impl_com_object_clone_drop!(QueryHeap);
 
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct Heap {
     pub this: *mut ID3D12Heap,
 }
 impl_com_object_set_get_name!(Heap);
 impl_com_object_refcount_named!(Heap);
 impl_com_object_clone_drop!(Heap);
-
 pub struct PIXSupport {}
 
 impl PIXSupport {
